@@ -19,9 +19,17 @@ class ServerController(BaseController):
     async def reset_status(self):
         return await self.admin_POST('/status/reset')
 
+    async def status_ready(self):
+        return await self.admin_GET('/status/ready')
+
+    async def status_live(self):
+        return await self.admin_GET('/status/live')
+
     async def get_features(self, query: str = None):
         params = {}
         if query:
             params["query"] = query
 
         return await self.admin_GET('/features', params=params)
+
+    ## TODO implement shutdown. Should this be a POST?
\ No newline at end of file
